# Instance Format for the Retrieval Optimization Problem

## Overview

The instance format for the Retrieval Optimization Problem (ROP) uses the file extension `.rop`.
Each instance file contains a sequence of whitespace-delimited numbers, where whitespace includes tabs, spaces, and newline characters.

## Header

The first line of the file contains an integer representing the number of pallets `n`.
The second line contains an integer representing the number of I/O-points `m`.
Pallets are indexed as `i=1,2,...,n` and I/O-points are indexed as `j=1,2,...,m`.
The third line contains the depot I/O-point index `j`, indicating the I/O-point where the tour starts and ends.

## Travel Costs Matrix

After the header, there is a `(n+m)*(n+m)` travel costs matrix that specifies the travel costs between all pairs of locations.
Locations are indexed as `l=1,2,...,n+m`, where locations `l=1,2,...,n` correspond to the `n` pallets and locations `l=n+1,n+2,...,n+m` correspond to the `m` I/O-points.

## Pallet Assignments and Retrieval Sequence

The final section of the file contains `n` lines, one for each pallet (the jth line in this section corresponds to the jth pallet).
The first column indicates at which specific I/O-point each pallet has to be retrieved.
The second column indicates the permutation in which the pallets have to be retrieved.
Depending on the exact problem variant considered, the first and/or second column of these last `n` lines may be ignored.

## Example Instance

Here is an example instance with `n=5` pallets, `m=2` I/O-points, and depot location `j=1`.
For example, moving from I/O-point `j=2` to pallet `i=3` (i.e., from location `l=j+n=7` to location `l=i=3`) costs 274.
Pallets `i=1` and `i=2` have to be retrieved at I/O-point `j=1`, whereas pallets `i=3`, `i=4`, and `i=5` have to be retrieved at I/O-point `j=2`.
Pallet `i=1` is the first pallet to be retrieved, followed by pallets `i=5`, `i=3`, `i=4`, and `i=2`.
~~~
5
2
1
  0 821 185  84  73 708 459
821 0   636 886 881 214 362
185 636   0 250 245 523 274
 84 886 250   0  11 773 524
 73 881 245  11   0 768 519
708 214 523 773 768   0 249
459 362 274 524 519 249   0
1 1
1 5
2 3
2 4
2 2
~~~

